@@ -9,8 +9,8 @@ class CoinbaseOAuth2(BaseOAuth2):
     name = 'coinbase'
     SCOPE_SEPARATOR = '+'
     DEFAULT_SCOPE = ['user', 'balance']
-    AUTHORIZATION_URL = 'https://coinbase.com/oauth/authorize'
-    ACCESS_TOKEN_URL = 'https://coinbase.com/oauth/token'
+    AUTHORIZATION_URL = 'https://www.coinbase.com/oauth/authorize'
+    ACCESS_TOKEN_URL = 'https://api.coinbase.com/oauth/token'
     REVOKE_TOKEN_URL = 'https://api.coinbase.com/oauth/revoke'
     ACCESS_TOKEN_METHOD = 'POST'
     REDIRECT_STATE = False
