@@ -18,7 +18,7 @@ class LegacyAuth(BaseAuth):
                self.setting('FORM_HTML')
 
     def auth_complete(self, *args, **kwargs):
-        """Completes loging process, must return user instance"""
+        """Completes login process, must return user instance"""
         if self.ID_KEY not in self.data:
             raise AuthMissingParameter(self, self.ID_KEY)
         kwargs.update({'response': self.data, 'backend': self})
