@@ -81,11 +81,14 @@ class LinkedinOAuth2(BaseLinkedinAuth, BaseOAuth2):
     REDIRECT_STATE = False
 
     def user_data(self, access_token, *args, **kwargs):
+        headers = self.user_data_headers() or {}
+        headers['Authorization'] = 'Bearer {access_token}'.format(
+            access_token=access_token
+        )
         return self.get_json(
             self.user_details_url(),
-            params={'oauth2_access_token': access_token,
-                    'format': 'json'},
-            headers=self.user_data_headers()
+            params={'format': 'json'},
+            headers=headers
         )
 
     def request_access_token(self, *args, **kwargs):
@@ -95,3 +98,19 @@ class LinkedinOAuth2(BaseLinkedinAuth, BaseOAuth2):
         return super(LinkedinOAuth2, self).request_access_token(
             *args, **kwargs
         )
+
+
+class LinkedinMobileOAuth2(LinkedinOAuth2):
+    name = 'linkedin-mobile-oauth2'
+
+    def user_data(self, access_token, *args, **kwargs):
+        headers = self.user_data_headers()
+        if not headers:
+            headers = {}
+        headers['Authorization'] = 'Bearer ' + access_token
+        headers['x-li-src'] = 'msdk'
+        return self.get_json(
+            self.user_details_url(),
+            params={'format': 'json'},
+            headers=headers
+        )
